@@ -42,7 +42,7 @@ def test_get_page_info():
         'isin': 'IRO1MSMI0001',
         'l18': 'فملی',
         'l30': 'ملی\u200c صنایع\u200c مس\u200c ایران\u200c',
-        'market': 'بازار اول (تابلوی اصلی) بورس',
+        'flow_name': 'بازار اول (تابلوی اصلی) بورس',
         'month_average_volume': 98322903,
         'sector_name': 'فلزات اساسی',
         'sector_pe': 15.4,
@@ -129,7 +129,7 @@ def test_get_page_info_no_free_float():
         'isin': 'IRO3BDYZ0001',
         'l18': 'دی',
         'l30': 'بانک دی',
-        'market': 'بازار دوم فرابورس',
+        'flow_name': 'بازار دوم فرابورس',
         'month_average_volume': 25836324,
         'sector_name': 'بانکها و موسسات اعتباری',
         'sector_pe': 16.69,
@@ -156,7 +156,7 @@ def test_get_page_info_no_eps():
         'isin': 'IRO1KALA0001',
         'l18': 'کالا',
         'l30': 'بورس کالای ایران',
-        'market': 'بازار اول (تابلوی فرعی) بورس',
+        'flow_name': 'بازار اول (تابلوی فرعی) بورس',
         'month_average_volume': 5720005,
         'sector_name': 'فعالیتهای کمکی به نهادهای مالی واسط',
         'sector_pe': 26.22,
@@ -180,7 +180,7 @@ def test_get_page_info_no_sector_pe():
         , 'free_float': 52
         , 'l30': 'گسترش\u200cسرمایه\u200cگذاری\u200cایران\u200cخودرو'
         , 'sector_name': 'خودرو و ساخت قطعات'
-        , 'market': 'بازار اول (تابلوی اصلی) بورس'
+        , 'flow_name': 'بازار اول (تابلوی اصلی) بورس'
         , 'month_average_volume': 212159873
         , 'l18': 'خگستر'
         , 'sector_pe': -32.11
@@ -581,3 +581,69 @@ def test_get_holders_without_cisin():
         with raises(NotImplementedError):
             inst.get_holders()
     get_identification.assert_called_once()
+
+
+@patch_get_content('fmelli_20210602_intraday.html')
+def test_get_intraday_general():
+    result = Instrument(1).get_intraday(
+        20210602, general=True, thresholds=True, closings=True, candles=True,
+        holders=True, yesterday_holders=True)
+    assert len(result) == 10
+    assert result['general'] == {
+        'l30': 'ملی\u200c صنایع\u200c مس\u200c ایران\u200c',
+        'l18': 'فملی',
+        'market': 'بازار بورس',
+        'flow_name': 'بازار اول (تابلوی اصلی) بورس',
+        'flow': 1,
+        'group_code': 'N1',
+        'cisin': 'IRO1MSMI0000',
+        'isin': 'IRO1MSMI0001',
+        'z': 200000000000,
+        'bvol': 10143702}
+    assert result['thresholds'].to_csv(line_terminator='\n') == (
+        ',time,tmax,tmin\n'
+        '0,1,13080.0,11840.0\n'
+        '1,63122,13000.0,11780.0\n')
+    assert result['closings'].iloc[-1].to_dict() == {
+        'date': '1400/3/12 13:08:41',
+        '?1': '-', 'pl': '12480', 'pc': '12460', 'pf': '12190', 'py': '12390',
+        'pmin': '12590', 'pmax': '12190', 'tno': '10219', 'tvol': '60394598',
+        'tval': '752545395210', '?2': '0', 'heven': '130841'}
+    assert result['candles'].iloc[-1].to_dict() == {
+        'time': '12:15', 'high': 12580, 'low': 12400, 'open': 12440,
+        'close': 12460, 'tvol': 7036930}
+    assert result['states'].iloc[-1].to_dict() == {
+        'date': 20210214, 'time': 1, 'state': 'A '}
+    assert result['trades'].iloc[-1].to_dict() == {
+        'time': '12:30:00', 'tvol': 750, 'pl': 12480, 'annulled': False}
+    assert len(result['holders']) == 0
+    yesterday_holders = result['yesterday_holders']
+    assert len(yesterday_holders) == 21
+    assert yesterday_holders.iloc[-1].to_dict() == {
+        'id': 21630, 'cisin': 'IRO1MSMI0000', 'shares': 2003857980,
+        'percent': 1.0, 'change': '',
+        'name': 'شرکت گروه توسعه مالی مهرآیندگان-سهامی عام-'}
+    assert result['client_types'] == {
+        'l_buy_count': 10,
+        'l_buy_percent': 13,
+        'l_buy_value': 97592925820,
+        'l_buy_volume': 7835930,
+        'l_mean_buy_price': 12454.542832822652,
+        'l_mean_sell_price': 12460.894315227768,
+        'l_sell_count': 15,
+        'l_sell_percent': 19,
+        'l_sell_value': 140726287530,
+        'l_sell_volume': 11293434,
+        'n_buy_count': 4389,
+        'n_buy_percent': 87,
+        'n_buy_value': 654952469390,
+        'n_buy_volume': 52558668,
+        'n_mean_buy_price': 12461.359739748352,
+        'n_mean_sell_price': 12460.378896109265,
+        'n_sell_count': 0,
+        'n_sell_percent': 81,
+        'n_sell_value': 611819107680,
+        'n_sell_volume': 49101164}
+    assert result['best_limits'].loc[133707].to_dict() == {
+        'row': 5, 'zd': 31, 'qd': 534434, 'pd': 12430, 'po': 12520,
+        'qo': 111906, 'zo': 15}
